@@ -35,10 +35,9 @@
 #include <QRegExp>
 #include <QStandardPaths>
 #include <QTextCodec>
+#include <QProcess>
 
 #include <KLocalizedString>
-#include <KProcess>
-#include <kglobal.h>
 #include <kencodingprober.h>
 
 #include "man2html.h"
@@ -130,9 +129,6 @@ MANProtocol::MANProtocol(const QByteArray &pool_socket, const QByteArray &app_so
 {
     assert(!_self);
     _self = this;
-    const QString common_dir = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "doc/HTML/en/kdoctools5-common/kde-default.css" );
-    const QString strPath=QString( "file:%1/en/kdoctools5-common" ).arg( common_dir );
-    m_cssPath=strPath.toLocal8Bit(); // ### TODO encode for CSS
     section_names << "0" << "0p" << "1" << "1p" << "2" << "3" << "3n" << "3p" << "4" << "5" << "6" << "7"
                   << "8" << "9" << "l" << "n";
 
@@ -211,10 +207,12 @@ QMap<QString, QString> MANProtocol::buildIndexMap(const QString &section)
 		    break;
 	    }
             if ( it_name == names.constEnd() ) {
-                KProcess proc;
-                proc << "whatis" << "-M" << (*it_dir) << "-w" << "*";
-                proc.setOutputChannelMode( KProcess::OnlyStdoutChannel );
-                proc.execute();
+                QProcess proc;
+                proc.setProgram("whatis");
+                proc.setArguments(QStringList() << "-M" << (*it_dir) << "-w" << "*");
+                proc.setProcessChannelMode( QProcess::ForwardedErrorChannel );
+                proc.start();
+                proc.waitForFinished();
                 QTextStream t( proc.readAllStandardOutput(), QIODevice::ReadOnly );
                 parseWhatIs( i, t, mark );
             }
@@ -237,14 +235,14 @@ QStringList MANProtocol::manDirectories()
     {
         // Translated pages in "<mandir>/<lang>" if the directory
         // exists
-        QStringList languages = KLocale::global()->languageList();
-
-        for (QStringList::ConstIterator it_lang = languages.constBegin();
-             it_lang != languages.constEnd();
-             it_lang++ )
+        QList<QLocale> locales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
+        for (QList<QLocale>::ConstIterator it_loc = locales.constBegin();
+             it_loc != locales.constEnd();
+             it_loc++ )
         {
-            if ( !(*it_lang).isEmpty() && (*it_lang) != QString("C") ) {
-                QString dir = (*it_dir) + '/' + (*it_lang);
+            QString lang = QLocale::languageToString((*it_loc).language());
+            if ( !lang.isEmpty() && lang!=QString("C") ) {
+                QString dir = (*it_dir) + '/' + lang;
 
                 struct stat sbuf;
 
@@ -500,7 +498,6 @@ void MANProtocol::get(const QUrl& url )
 
     if (pageFound)
     {
-       setResourcePath(m_cssPath);
        setCssFile(m_manCSSFile);
        m_outputBuffer.open(QIODevice::WriteOnly);
        const QByteArray filename=QFile::encodeName(foundPages[0]);
@@ -542,12 +539,14 @@ char *MANProtocol::readManPage(const char *_filename)
     //QString file_mimetype = KMimeType::findByPath(QString(filename), 0, false)->name();
     if (QString(filename).contains("sman", Qt::CaseInsensitive)) //file_mimetype == "text/html" || )
     {
-        KProcess proc;
+        QProcess proc;
         // Determine path to sgml2roff, if not already done.
         getProgramPath();
-        proc << mySgml2RoffPath << filename;
-        proc.setOutputChannelMode( KProcess::OnlyStdoutChannel );
-        proc.execute();
+        proc.setProgram(mySgml2RoffPath);
+        proc.setArguments(QStringList() << filename);
+        proc.setProcessChannelMode( QProcess::ForwardedErrorChannel );
+        proc.start();
+        proc.waitForFinished();
         array = proc.readAllStandardOutput();
     }
     else
