@@ -21,7 +21,7 @@
 #define KIO_SMTP_DEBUG_H
 
 #include <QLoggingCategory>
-Q_DECLARE_LOGGING_CATEGORY(KIO_SMTP_LOG)
+Q_DECLARE_LOGGING_CATEGORY(KIO_SFTP_LOG)
 
 #endif 
 
