@@ -163,6 +163,6 @@ bool TextCreator::create(const QString &path, int width, int height, QImage &img
 
 ThumbCreator::Flags TextCreator::flags() const
 {
-    return (Flags)(DrawFrame | BlendIcon);
+    return (Flags)BlendIcon;
 }
 
